from classicML.DecisionTree import *
from classicML.NeuralNetwork import *

from classicML.DecisionTree.tree_model.decision_tree import DecisionTree
from classicML.DecisionTree.tree_plot import plot_tree

from classicML.NeuralNetwork.nn_model.back_propagation_neural_network import BackPropagationNeuralNetwork
from classicML.NeuralNetwork.nn_model.back_propagation_neural_network import BackPropagationNeuralNetwork as BPNN
from classicML.NeuralNetwork.nn_plot.plot_nn import plot_history


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="classicML",
    version="0.2.1-rc1",
    author="Steve Sun",
    author_email="s1638650145@gmail.com",
    description="An easy-to-use ML framework",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/sun1638650145/classicML",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        'numpy>=1.18.4',
        'pandas>=1.0.3',
        'matplotlib>=3.2.1',
        'scikit-learn>=0.23.0'
    ],
)
